Returns non-scientific metadata (timestamps, runtimes, logs, warnings, thread caps, parallel flags, timeouts).
Arguments
- x
A result list as returned by
cs_run_single()or read from pins.
Returns non-scientific metadata (timestamps, runtimes, logs, warnings, thread caps, parallel flags, timeouts).
A result list as returned by cs_run_single() or read from pins.