Skip to contents

Reads a batch artifact pinned by cs_consolidate() and returns the list of run result objects stored under results.

Usage

cs_read_batch(board, batch_id)

Arguments

board

A pins board containing batch pins.

batch_id

Integer batch id or a full pin name (batch_{id}).

Value

A list of run result objects.