Skip to contents

Returns a canonicalized object suitable for bitwise identity checks. This excludes non-deterministic and non-scientific fields (timestamps, runtimes, logs, warnings).

Usage

cs_science_payload(x)

Arguments

x

A result list as returned by cs_run_single() or read from pins.

Value

A list with elements att, qst, scores, and meta.