Converts a supported CausalStress single-run result, list of run results, or existing data frame into the package's flattened run-row format.
Arguments
- x
A result object from
cs_run_single(),cs_run_seeds(), or a list thereof.
Converts a supported CausalStress single-run result, list of run results, or existing data frame into the package's flattened run-row format.
A result object from cs_run_single(), cs_run_seeds(), or a list thereof.