Applies cs_tidy() to each result object in a batch and returns a single
combined tibble.
Arguments
- batch_results
A list of run result objects (from
cs_read_batch()).
Applies cs_tidy() to each result object in a batch and returns a single
combined tibble.
A list of run result objects (from cs_read_batch()).