Skip to contents

cs_tidy_run() is a convenience helper that flattens the rich list returned by cs_run_single() into a one-row tibble, using the same column structure as cs_run_seeds() and cs_run_grid().

Usage

cs_tidy_run(result)

Arguments

result

A list as returned by cs_run_single().

Value

A tibble with a single row and the same columns as cs_run_seeds(), e.g.: dgp_id, estimator_id, n, seed, oracle, supports_qst, true_att, est_att, att_error, att_abs_error, att_ci_lo, att_ci_hi, att_covered, n_boot_ok, estimator_pkgs, log, etc.

Details

This is useful when:

  • you call cs_run_single() interactively for debugging or small experiments,

  • and want results that are directly comparable to multi-seed campaigns.