R/cs-accessors.R
cs_read_batch.Rd
Reads a batch artifact pinned by cs_consolidate() and returns the list of run result objects stored under results.
cs_consolidate()
results
cs_read_batch(board, batch_id)
A pins board containing batch pins.
Integer batch id or a full pin name (batch_{id}).
batch_{id}
A list of run result objects.