Placebo tilted propensity synthetic DGP (sharp null, v1.4.0)
Source:R/dgp-synth-placebo-tilted.R
dgp_synth_placebo_tilted_v140.RdVersion bump that reduces propensity tilt to moderate levels (coefficients 0.6, 0.8) to ensure unimodality.
Arguments
- n
Integer, number of observations.
- seed
Optional seed for reproducibility (passed to
cs_set_rng()).- include_truth
Logical; if TRUE, include oracle truth tables where supported.
- oracle_only
Logical; if TRUE, return only columns needed for oracle truth generation where supported.